@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
 # Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
@@ -21,14 +20,14 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-from __future__ import print_function
-import gammu
 
 import sys
+
+import gammu
+
 if len(sys.argv) != 3:
     print(
-        'This requires two parameter with file names!'
-        ' First is input, second output.'
+        "This requires two parameter with file names!" " First is input, second output."
     )
     sys.exit(1)
 
