@@ -1,8 +1,7 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2017 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
 # This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
@@ -21,12 +20,13 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-from __future__ import print_function
-import gammu
+
 import sys
 
+import gammu
+
 state_machine = gammu.StateMachine()
-if len(sys.argv) >= 2:
+if len(sys.argv) > 2:
     state_machine.ReadConfig(Filename=sys.argv[1])
     del sys.argv[1]
 else:
@@ -37,4 +37,4 @@ status = state_machine.GetBatteryCharge()
 
 for x in status:
     if status[x] != -1:
-        print(("{0:20}: {1}".format(x, status[x])))
+        print(f"{x:20}: {status[x]}")
