@@ -1,8 +1,7 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2017 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
 # This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
@@ -21,22 +20,23 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-from __future__ import print_function
-import gammu
+
 import sys
 
+import gammu
+
 
 def main():
     # Global debug level
     gammu.SetDebugFile(sys.stderr)
-    gammu.SetDebugLevel('textall')
+    gammu.SetDebugLevel("textall")
 
     state_machine = gammu.StateMachine()
     state_machine.ReadConfig()
 
     # Use global debug stub regardless configuration
     c = state_machine.GetConfig(0)
-    c['UseGlobalDebugFile'] = True
+    c["UseGlobalDebugFile"] = True
     state_machine.SetConfig(0, c)
 
     state_machine.Init()
@@ -45,12 +45,12 @@ def main():
     model = state_machine.GetModel()
     imei = state_machine.GetIMEI()
     firmware = state_machine.GetFirmware()
-    print('Phone infomation:')
-    print(('{0:<15}: {1}'.format('Manufacturer', manufacturer)))
-    print(('{0:<15}: {1} ({2})'.format('Model', model[0], model[1])))
-    print(('{0:<15}: {1}'.format('IMEI', imei)))
-    print(('{0:<15}: {1}'.format('Firmware', firmware[0])))
+    print("Phone infomation:")
+    print("{:<15}: {}".format("Manufacturer", manufacturer))
+    print("{:<15}: {} ({})".format("Model", model[0], model[1]))
+    print("{:<15}: {}".format("IMEI", imei))
+    print("{:<15}: {}".format("Firmware", firmware[0]))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
