@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
 # Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
@@ -21,10 +20,11 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-from __future__ import print_function
-import gammu
+
 import sys
 
+import gammu
+
 # Create object for talking with phone
 state_machine = gammu.StateMachine()
 
@@ -40,7 +40,7 @@ state_machine.Init()
 
 # Check whether we have a number to dial
 if len(sys.argv) != 2:
-    print('Usage: dialvoice.py NUMBER')
+    print("Usage: dialvoice.py NUMBER")
     sys.exit(1)
 
 # Dial a number
