@@ -1,8 +1,7 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2017 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
 # This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
@@ -21,7 +20,7 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-from __future__ import print_function
+
 import gammu
 
 
@@ -32,7 +31,7 @@ def main():
 
     status = state_machine.GetSMSStatus()
 
-    remain = status['SIMUsed'] + status['PhoneUsed'] + status['TemplatesUsed']
+    remain = status["SIMUsed"] + status["PhoneUsed"] + status["TemplatesUsed"]
 
     start = True
 
@@ -42,22 +41,20 @@ def main():
                 sms = state_machine.GetNextSMS(Start=True, Folder=0)
                 start = False
             else:
-                sms = state_machine.GetNextSMS(
-                    Location=sms[0]['Location'], Folder=0
-                )
+                sms = state_machine.GetNextSMS(Location=sms[0]["Location"], Folder=0)
             remain = remain - len(sms)
 
             for m in sms:
                 print()
-                print('{0:<15}: {1}'.format('Number', m['Number']))
-                print('{0:<15}: {1}'.format('Date', str(m['DateTime'])))
-                print('{0:<15}: {1}'.format('State', m['State']))
-                print('\n{0}'.format(m['Text']))
+                print("{:<15}: {}".format("Number", m["Number"]))
+                print("{:<15}: {}".format("Date", str(m["DateTime"])))
+                print("{:<15}: {}".format("State", m["State"]))
+                print("\n{}".format(m["Text"]))
     except gammu.ERR_EMPTY:
         # This error is raised when we've reached last entry
         # It can happen when reported status does not match real counts
-        print('Failed to read all messages!')
+        print("Failed to read all messages!")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
