@@ -1,8 +1,7 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2017 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
 # This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
@@ -22,13 +21,14 @@
 #
 """Sample script to show how to same SMS to multiple recipients"""
 
-from __future__ import print_function
-import gammu
+
 import sys
 
+import gammu
+
 # Check parameters count
-if len(sys.argv) < 3 or sys.argv[1] in ['--help', '-h', '-?']:
-    print('Usage: mass-sms <TEXT> [number]...')
+if len(sys.argv) < 3 or sys.argv[1] in ["--help", "-h", "-?"]:
+    print("Usage: mass-sms <TEXT> [number]...")
     sys.exit(1)
 
 # Configure Gammu
@@ -37,12 +37,12 @@ state_machine.ReadConfig()
 state_machine.Init()
 
 # Prepare SMS template
-message = {'Text': sys.argv[1], 'SMSC': {'Location': 1}}
+message = {"Text": sys.argv[1], "SMSC": {"Location": 1}}
 
 # Send SMS to all recipients on command line
 for number in sys.argv[2:]:
-    message['Number'] = number
+    message["Number"] = number
     try:
         state_machine.SendSMS(message)
     except gammu.GSMError as exc:
-        print('Sending to {0} failed: {1}'.format(number, exc))
+        print(f"Sending to {number} failed: {exc}")
