@@ -1,8 +1,7 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2017 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
 # This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
@@ -21,17 +20,18 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-from __future__ import print_function
-import gammu
 
 import sys
+
+import gammu
+
 if len(sys.argv) != 2:
-    print('This requires parameter with hex encoded PDU data!')
+    print("This requires parameter with hex encoded PDU data!")
     sys.exit(1)
 
 # Global debug level
 gammu.SetDebugFile(sys.stderr)
-gammu.SetDebugLevel('textall')
+gammu.SetDebugLevel("textall")
 
-sms = gammu.DecodePDU(sys.argv[1].decode('hex'))
+sms = gammu.DecodePDU(sys.argv[1].decode("hex"))
 print(sms)
