@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
 # Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
@@ -21,12 +20,13 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-from __future__ import print_function
-import gammu
-import os
+
 import errno
+import os
 import re
 
+import gammu
+
 
 def createFolderIfNotExist(path):
     try:
@@ -77,7 +77,7 @@ def saveSMS(mysms, all_contacts):
     with open(os.path.join(mydir, myfile), "a") as handle:
         for i in mysms:
             handle.write(i["Text"].encode("UTF-8"))
-        handle.write(u"\n".encode("UTF-8"))
+        handle.write(b"\n")
 
 
 def getContacts(state_machine):
@@ -112,7 +112,7 @@ def getContacts(state_machine):
     except gammu.ERR_EMPTY:
         # error is raised if memory is empty (this induces wrong reported
         # memory status)
-        print('Failed to read contacts!')
+        print("Failed to read contacts!")
 
     return contacts
 
@@ -146,7 +146,7 @@ def getAndDeleteAllSMS(state_machine):
     except gammu.ERR_EMPTY:
         # error is raised if memory is empty (this induces wrong reported
         # memory status)
-        print('Failed to read messages!')
+        print("Failed to read messages!")
 
     # Link all SMS when there are concatenated messages
     entries = gammu.LinkSMS(entries)
