@@ -1,8 +1,7 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2017 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
 # This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
@@ -22,20 +21,21 @@
 #
 """Sample script to show how to send SMS through SMSD"""
 
-from __future__ import print_function
-import gammu.smsd
+
 import sys
 
-smsd = gammu.smsd.SMSD('/etc/gammu-smsdrc')
+import gammu.smsd
+
+smsd = gammu.smsd.SMSD("/etc/gammu-smsdrc")
 
 if len(sys.argv) != 2:
-    print('Usage: smsd-inject.py RECIPIENT_NUMBER')
+    print("Usage: smsd-inject.py RECIPIENT_NUMBER")
     sys.exit(1)
 
 message = {
-    'Text': 'python-gammu testing message',
-    'SMSC': {'Location': 1},
-    'Number': sys.argv[1]
+    "Text": "python-gammu testing message",
+    "SMSC": {"Location": 1},
+    "Number": sys.argv[1],
 }
 
 smsd.InjectSMS([message])
