@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
 # Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
@@ -25,10 +24,11 @@ Example for reading data from phone and convering it to and from
 vCard, vTodo, vCalendar
 """
 
-from __future__ import print_function
-import gammu
+
 import sys
 
+import gammu
+
 
 def main():
     state_machine = gammu.StateMachine()
@@ -67,7 +67,7 @@ def main():
     # For memory entry
 
     # Read entry from phone
-    entry = state_machine.GetNextMemory(Start=True, Type='ME')
+    entry = state_machine.GetNextMemory(Start=True, Type="ME")
 
     # Convert it to vCard
     vc_entry = gammu.EncodeVCARD(entry)
@@ -76,5 +76,5 @@ def main():
     print(gammu.DecodeVCARD(vc_entry))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
