@@ -21,6 +21,7 @@
 
 /* SMS related conversions */
 
+#define PY_SSIZE_T_CLEAN
 #include "convertors.h"
 #include "misc.h"
 
@@ -683,13 +684,9 @@ PyObject *UDHToPython(GSM_UDHHeader * udh)
 		return NULL;
 
 	val = Py_BuildValue(
-#if PY_MAJOR_VERSION >= 3
 		"{s:s,s:y#,s:i,s:i,s:i,s:i}",
-#else
-		"{s:s,s:s#,s:i,s:i,s:i,s:i}",
-#endif
 		"Type", type,
-		"Text", udh->Text, udh->Length,
+		"Text", udh->Text, (Py_ssize_t)udh->Length,
 		"ID8bit", udh->ID8bit,
 		"ID16bit", udh->ID16bit,
 		"PartNumber", udh->PartNumber,
