@@ -1,7 +1,6 @@
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2017 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
 # This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
@@ -19,10 +18,12 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-import unittest
-import tempfile
-import gammu
 import os
+import tempfile
+import unittest
+
+import gammu
+
 from .test_sms import PDU_DATA
 
 
@@ -32,57 +33,57 @@ class ConfigTest(unittest.TestCase):
         state_machine.SetConfig(
             0,
             {
-                'StartInfo': True,
-                'UseGlobalDebugFile': True,
-                'DebugFile': None,
-                'SyncTime': True,
-                'Connection': 'at',
-                'LockDevice': True,
-                'DebugLevel': 'textalldate',
-                'Device': '',
-                'Model': '',
+                "StartInfo": True,
+                "UseGlobalDebugFile": True,
+                "DebugFile": None,
+                "SyncTime": True,
+                "Connection": "at",
+                "LockDevice": True,
+                "DebugLevel": "textalldate",
+                "Device": "",
+                "Model": "",
             },
         )
         cfg = state_machine.GetConfig(0)
-        self.assertEqual(cfg['StartInfo'], 1)
+        self.assertEqual(cfg["StartInfo"], 1)
 
     def test_config_string(self):
         state_machine = gammu.StateMachine()
         state_machine.SetConfig(
             0,
             {
-                'StartInfo': 'yes',
-                'UseGlobalDebugFile': 'no',
-                'DebugFile': 'dbg.log',
-                'SyncTime': 'true',
-                'Connection': 'fbus',
-                'LockDevice': 'FALSE',
-                'DebugLevel': 'textall',
-                'Device': '',
-                'Model': '',
+                "StartInfo": "yes",
+                "UseGlobalDebugFile": "no",
+                "DebugFile": "dbg.log",
+                "SyncTime": "true",
+                "Connection": "fbus",
+                "LockDevice": "FALSE",
+                "DebugLevel": "textall",
+                "Device": "",
+                "Model": "",
             },
         )
         cfg = state_machine.GetConfig(0)
-        self.assertEqual(cfg['StartInfo'], 1)
+        self.assertEqual(cfg["StartInfo"], 1)
 
     def test_config_none(self):
         state_machine = gammu.StateMachine()
         state_machine.SetConfig(
             0,
             {
-                'StartInfo': None,
-                'UseGlobalDebugFile': None,
-                'DebugFile': 'dbg.log',
-                'SyncTime': 'true',
-                'Connection': 'dlr3',
-                'LockDevice': 'NO',
-                'DebugLevel': 'binary',
-                'Device': '',
-                'Model': '',
+                "StartInfo": None,
+                "UseGlobalDebugFile": None,
+                "DebugFile": "dbg.log",
+                "SyncTime": "true",
+                "Connection": "dlr3",
+                "LockDevice": "NO",
+                "DebugLevel": "binary",
+                "Device": "",
+                "Model": "",
             },
         )
         cfg = state_machine.GetConfig(0)
-        self.assertEqual(cfg['StartInfo'], 0)
+        self.assertEqual(cfg["StartInfo"], 0)
 
     def test_init_error(self):
         self.assertRaises(TypeError, gammu.StateMachine, Bar=1)
@@ -90,7 +91,7 @@ class ConfigTest(unittest.TestCase):
 
 class DebugTest(unittest.TestCase):
     def setUp(self):
-        gammu.SetDebugLevel('textall')
+        gammu.SetDebugLevel("textall")
 
     def check_operation(self, filename, handle=None):
         """
@@ -101,14 +102,14 @@ class DebugTest(unittest.TestCase):
         if handle:
             handle.close()
         if filename is not None:
-            with open(filename, 'r') as handle:
-                self.assertTrue('SMS type: Status report' in handle.read())
+            with open(filename) as handle:
+                self.assertTrue("SMS type: Status report" in handle.read())
 
     def test_file(self):
-        testfile = tempfile.NamedTemporaryFile(suffix='.debug', delete=False)
+        testfile = tempfile.NamedTemporaryFile(suffix=".debug", delete=False)
         testfile.close()
         try:
-            handle = open(testfile.name, 'w')
+            handle = open(testfile.name, "w")
             gammu.SetDebugFile(handle)
             self.check_operation(testfile.name, handle)
         finally:
@@ -116,7 +117,7 @@ class DebugTest(unittest.TestCase):
             os.unlink(testfile.name)
 
     def test_filename(self):
-        testfile = tempfile.NamedTemporaryFile(suffix='.debug', delete=False)
+        testfile = tempfile.NamedTemporaryFile(suffix=".debug", delete=False)
         testfile.close()
         try:
             gammu.SetDebugFile(testfile.name)
@@ -130,14 +131,14 @@ class DebugTest(unittest.TestCase):
         self.check_operation(None)
 
     def test_nothing(self):
-        gammu.SetDebugLevel('nothing')
-        testfile = tempfile.NamedTemporaryFile(suffix='.debug', delete=False)
+        gammu.SetDebugLevel("nothing")
+        testfile = tempfile.NamedTemporaryFile(suffix=".debug", delete=False)
         testfile.close()
         try:
             gammu.SetDebugFile(testfile.name)
             self.check_operation(None)
-            with open(testfile.name, 'r') as handle:
-                self.assertEqual('', handle.read())
+            with open(testfile.name) as handle:
+                self.assertEqual("", handle.read())
         finally:
             gammu.SetDebugFile(None)
             os.unlink(testfile.name)
