@@ -1,4 +1,3 @@
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
 # Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
@@ -20,13 +19,14 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 import unittest
+
 import gammu.data
 
 
 class DataTest(unittest.TestCase):
     def test_connections(self):
-        self.assertTrue('at' in gammu.data.Connections)
+        self.assertTrue("at" in gammu.data.Connections)
 
     def test_errors(self):
-        self.assertTrue('ERR_INSTALL_NOT_FOUND' in gammu.data.Errors)
-        self.assertEqual(gammu.data.ErrorNumbers[73], 'ERR_NETWORK_ERROR')
+        self.assertTrue("ERR_INSTALL_NOT_FOUND" in gammu.data.Errors)
+        self.assertEqual(gammu.data.ErrorNumbers[73], "ERR_NETWORK_ERROR")
