@@ -1,4 +1,3 @@
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
 # Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
@@ -19,27 +18,28 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-from __future__ import print_function
-from .test_dummy import DummyTest
-import gammu.smsd
+
 import os
 import os.path
-import threading
-import time
 import platform
 import sqlite3
+import threading
+import time
 import unittest
 
+import gammu.smsd
+
+from .test_dummy import DummyTest
 
 MESSAGE_1 = {
-    'Text': 'python-gammu testing message',
-    'SMSC': {'Location': 1},
-    'Number': '1234567890'
+    "Text": "python-gammu testing message",
+    "SMSC": {"Location": 1},
+    "Number": "1234567890",
 }
 MESSAGE_2 = {
-    'Text': 'python-gammu second testing message',
-    'SMSC': {'Location': 1},
-    'Number': '1234567890'
+    "Text": "python-gammu second testing message",
+    "SMSC": {"Location": 1},
+    "Number": "1234567890",
 }
 
 
@@ -48,9 +48,7 @@ def get_script():
 
     It returns correct script matching used Gammu version.
     """
-    version = tuple(
-        [int(x) for x in gammu.Version()[0].split('.')]
-    )
+    version = tuple(int(x) for x in gammu.Version()[0].split("."))
 
     if version < (1, 36, 7):
         dbver = 14
@@ -61,24 +59,20 @@ def get_script():
     else:
         dbver = 17
 
-    print('Gammu version {0}, SMSD DB version {1}'.format(version, dbver))
+    print(f"Gammu version {version}, SMSD DB version {dbver}")
 
-    return os.path.join(
-        os.path.dirname(__file__),
-        'data',
-        'sqlite-{0}.sql'.format(dbver)
-    )
+    return os.path.join(os.path.dirname(__file__), "data", f"sqlite-{dbver}.sql")
 
 
 class SMSDDummyTest(DummyTest):
     def setUp(self):
-        if platform.system() == 'Windows':
-            raise unittest.SkipTest('SMSD testing not supported on Windows (no DBI driver)')
-        super(SMSDDummyTest, self).setUp()
-        database = sqlite3.connect(
-            os.path.join(self.test_dir, 'smsd.db')
-        )
-        with open(get_script(), 'r') as handle:
+        if platform.system() == "Windows":
+            raise unittest.SkipTest(
+                "SMSD testing not supported on Windows (no DBI driver)"
+            )
+        super().setUp()
+        database = sqlite3.connect(os.path.join(self.test_dir, "smsd.db"))
+        with open(get_script()) as handle:
             database.executescript(handle.read())
 
     def get_smsd(self):
@@ -111,22 +105,22 @@ class SMSDDummyTest(DummyTest):
             retries = 0
             while retries < 2:
                 status = smsd.GetStatus()
-                if status['Sent'] >= 2:
+                if status["Sent"] >= 2:
                     break
                 time.sleep(10)
                 retries += 1
 
             self.assertEqual(
-                status['Received'],
+                status["Received"],
                 2,
-                'Messages were not received as expected ({0:d})!'.format(
-                status['Received'])
+                "Messages were not received as expected ({:d})!".format(
+                    status["Received"]
+                ),
             )
             self.assertEqual(
-                status['Sent'],
+                status["Sent"],
                 2,
-                'Messages were not sent as expected ({0:d})!'.format(
-                status['Sent'])
+                "Messages were not sent as expected ({:d})!".format(status["Sent"]),
             )
 
             time.sleep(1)
